==> react-native-ui-xep-0.1.28.tgz: package/src/atoms/modal/Modal.tsx <==
import React, { FC, ReactNode } from 'react';
import { Button } from '../button/Button';
import {
  ModalProps,
  Modal as ModalX,
  StatusBar,
  View,
  ScrollView,
  TouchableOpacity,
  TouchableWithoutFeedback,
} from 'react-native';
import { Text } from 'native-base';
import { ButtonTypeProps } from '../button/Button';
import { styles } from './styles';

type Props = ModalProps & {
  title: string;
  type?: 'custom' | 'customContent';
  message?: string;
  text?: string;
  titleProps?: any;
  textProps?: any;
  buttonText?: string;
  buttonType?: ButtonTypeProps;
  onButtonConfirm?: () => void;
  hideDivider?: boolean;
  close?: any;
  children?: ReactNode;
};

export const Modal: FC<Props> = (props: Props) => {
  const {
    children,
    close,
    text,
    title,
    titleProps,
    textProps,
    buttonType,
    buttonText,
    onButtonConfirm,
    hideDivider,
    type,
  } = props;
  const renderModalDefault = (titleStyle?: object, textStyle?: object) => {
    return (
      <ModalX
        animationType="slide"
        transparent={true}
        // visible={visible}
        onRequestClose={close}
        {...props}
      >
        <StatusBar translucent backgroundColor="rgba(0, 0, 0, 0.5)" />
        <TouchableOpacity style={styles.centeredView} onPress={close}>
          <TouchableWithoutFeedback>
            <View style={styles.modalView}>
              <ScrollView>
                <Text
                  style={
                    titleProps?.style !== undefined
                      ? { ...titleStyle, ...(titleProps?.style as object) }
                      : titleStyle
                  }
                >
                  {title}
                </Text>
                {(hideDivider === undefined || !hideDivider) && (
                  <View style={styles.horizontalLine} />
                )}
                <Text
                  style={
                    textProps?.style !== undefined
                      ? { ...textStyle, ...(textProps?.style as object) }
                      : textStyle
                  }
                >
                  {text}
                </Text>
                <Button
                  type={buttonType}
                  style={styles.button}
                  onPress={onButtonConfirm}
                >
                  {buttonText ?? 'Return'}
                </Button>
                {children}
              </ScrollView>
            </View>
          </TouchableWithoutFeedback>
        </TouchableOpacity>
      </ModalX>
    );
  };
  const renderModelCustomContent = (titleStyle?: object) => {
    return (
      <ModalX
        animationType="slide"
        transparent={true}
        // visible={visible}
        onRequestClose={close}
        {...props}
      >
        <StatusBar translucent backgroundColor="rgba(0, 0, 0, 0.5)" />
        <TouchableOpacity style={styles.centeredView} onPress={close}>
          <TouchableWithoutFeedback>
            <View style={styles.modalView}>
              <ScrollView>
                <Text
                  style={
                    titleProps?.style !== undefined
                      ? { ...titleStyle, ...(titleProps?.style as object) }
                      : titleStyle
                  }
                >
                  {title}
                </Text>
                {(hideDivider === undefined || !hideDivider) && (
                  <View style={styles.horizontalLine} />
                )}
                {children}
                <Button
                  type={buttonType}
                  style={styles.button}
                  onPress={onButtonConfirm}
                >
                  {buttonText ?? 'Return'}
                </Button>
              </ScrollView>
            </View>
          </TouchableWithoutFeedback>
        </TouchableOpacity>
      </ModalX>
    );
  };
  switch (type) {
    case 'custom':
      return (
        <ModalX
          animationType="slide"
          transparent={true}
          {...props}
          onRequestClose={close}
        >
          <StatusBar translucent backgroundColor="rgba(0, 0, 0, 0.5)" />
          <TouchableOpacity style={styles.centeredView} onPress={close}>
            <TouchableWithoutFeedback>
              <View style={styles.modalView}>{children}</View>
            </TouchableWithoutFeedback>
          </TouchableOpacity>
        </ModalX>
      );
    case 'customContent':
      return renderModelCustomContent(styles.defaultTitle);
    default:
      return renderModalDefault(styles.defaultTitle, styles.defaultText);
  }
};

==> react-native-ui-xep-0.1.30.tgz: package/src/atoms/modal/Modal.tsx <==
import React, { FC, ReactNode } from 'react';
import { Button } from '../button/Button';
import {
  ModalProps,
  Modal as ModalX,
  StatusBar,
  View,
  ScrollView,
  TouchableOpacity,
  TouchableWithoutFeedback,
} from 'react-native';
import { Text } from 'native-base';
import { ButtonTypeProps } from '../button/Button';
import { styles } from './styles';
export type ConfirmModalProps = {
  rightButtonLabel?: string;
  leftButtonLabel?: string;
  leftButtonCallback: () => void;
  rightButtonCallback: () => void;
  leftButtonType?: ButtonTypeProps;
  rightButtonType?: ButtonTypeProps;
};
type Props = ModalProps & {
  title: string;
  type?: 'custom' | 'customContent' | 'confirmModal';
  message?: string;
  text?: string;
  titleProps?: any;
  textProps?: any;
  buttonText?: string;
  buttonType?: ButtonTypeProps;
  onButtonConfirm?: () => void;
  hideDivider?: boolean;
  close?: any;
  children?: ReactNode;
  confirmModalProps?: ConfirmModalProps;
};

export const Modal: FC<Props> = (props: Props) => {
  const {
    children,
    close,
    text,
    title,
    titleProps,
    textProps,
    buttonType,
    buttonText,
    onButtonConfirm,
    hideDivider,
    type,
    confirmModalProps,
  } = props;
  const renderModalDefault = (titleStyle?: object, textStyle?: object) => {
    return (
      <ModalX
        animationType="slide"
        transparent={true}
        // visible={visible}
        onRequestClose={close}
        {...props}
      >
        <StatusBar translucent backgroundColor="rgba(0, 0, 0, 0.5)" />
        <TouchableOpacity style={styles.centeredView} onPress={close}>
          <TouchableWithoutFeedback>
            <View style={styles.modalView}>
              <ScrollView>
                <Text
                  style={
                    titleProps?.style !== undefined
                      ? { ...titleStyle, ...(titleProps?.style as object) }
                      : titleStyle
                  }
                >
                  {title}
                </Text>
                {(hideDivider === undefined || !hideDivider) && (
                  <View style={styles.horizontalLine} />
                )}
                <Text
                  style={
                    textProps?.style !== undefined
                      ? { ...textStyle, ...(textProps?.style as object) }
                      : textStyle
                  }
                >
                  {text}
                </Text>
                <Button
                  type={buttonType}
                  style={styles.button}
                  onPress={onButtonConfirm}
                >
                  {buttonText ?? 'Return'}
                </Button>
                {children}
              </ScrollView>
            </View>
          </TouchableWithoutFeedback>
        </TouchableOpacity>
      </ModalX>
    );
  };
  const renderModelConfirm = (titleStyle?: object, textStyle?: object) => {
    const {
      rightButtonLabel,
      leftButtonLabel,
      leftButtonCallback,
      rightButtonCallback,
      leftButtonType,
      rightButtonType,
    } = confirmModalProps!;
    return (
      <ModalX
        animationType="slide"
        transparent={true}
        // visible={visible}
        onRequestClose={close}
        {...props}
      >
        <StatusBar translucent backgroundColor="rgba(0, 0, 0, 0.5)" />
        <TouchableOpacity style={styles.centeredView} onPress={close}>
          <TouchableWithoutFeedback>
            <View style={styles.modalView}>
              <ScrollView>
                <Text
                  style={
                    titleProps?.style !== undefined
                      ? { ...titleStyle, ...(titleProps?.style as object) }
                      : titleStyle
                  }
                >
                  {title}
                </Text>
                {(hideDivider === undefined || !hideDivider) && (
                  <View style={styles.horizontalLine} />
                )}
                <Text
                  style={
                    textProps?.style !== undefined
                      ? { ...textStyle, ...(textProps?.style as object) }
                      : textStyle
                  }
                >
                  {text}
                </Text>
                <View style={styles.rowBox}>
                  <Button
                    type={leftButtonType ?? 'success'}
                    style={styles.confirmButton}
                    onPress={leftButtonCallback}
                  >
                    {leftButtonLabel ?? 'Yes'}
                  </Button>
                  <Button
                    type={rightButtonType ?? 'danger'}
                    style={styles.confirmButton}
                    onPress={rightButtonCallback}
                  >
                    {rightButtonLabel ?? 'No'}
                  </Button>
                </View>
              </ScrollView>
            </View>
          </TouchableWithoutFeedback>
        </TouchableOpacity>
      </ModalX>
    );
  };
  const renderModelCustomContent = (titleStyle?: object) => {
    return (
      <ModalX
        animationType="slide"
        transparent={true}
        // visible={visible}
        onRequestClose={close}
        {...props}
      >
        <StatusBar translucent backgroundColor="rgba(0, 0, 0, 0.5)" />
        <TouchableOpacity style={styles.centeredView} onPress={close}>
          <TouchableWithoutFeedback>
            <View style={styles.modalView}>
              <ScrollView>
                <Text
                  style={
                    titleProps?.style !== undefined
                      ? { ...titleStyle, ...(titleProps?.style as object) }
                      : titleStyle
                  }
                >
                  {title}
                </Text>
                {(hideDivider === undefined || !hideDivider) && (
                  <View style={styles.horizontalLine} />
                )}
                {children}
                <Button
                  type={buttonType}
                  style={styles.button}
                  onPress={onButtonConfirm}
                >
                  {buttonText ?? 'Return'}
                </Button>
              </ScrollView>
            </View>
          </TouchableWithoutFeedback>
        </TouchableOpacity>
      </ModalX>
    );
  };
  switch (type) {
    case 'custom':
      return (
        <ModalX
          animationType="slide"
          transparent={true}
          {...props}
          onRequestClose={close}
        >
          <StatusBar translucent backgroundColor="rgba(0, 0, 0, 0.5)" />
          <TouchableOpacity style={styles.centeredView} onPress={close}>
            <TouchableWithoutFeedback>
              <View style={styles.modalView}>{children}</View>
            </TouchableWithoutFeedback>
          </TouchableOpacity>
        </ModalX>
      );
    case 'customContent':
      return renderModelCustomContent(styles.defaultTitle);
    case 'confirmModal':
      return renderModelConfirm(styles.defaultTitle, styles.defaultText);
    default:
      return renderModalDefault(styles.defaultTitle, styles.defaultText);
  }
};
